@@ -49,7 +49,8 @@ from archive_handlers import ZipfileHandler, TarfileHandler, create_handler, \
 from django_config import DjangoConfig, django_config_from_json
 from generate_settings import generate_settings_file, simulated_install
 from utils import app_module_name_to_dir, write_json, find_files, \
-                  get_deployed_settings_module, import_module
+                  get_deployed_settings_module, import_module, \
+                  get_settings_file_directory, get_python_path
 from validation_results import *
 import command
 import parse_requirements
@@ -155,7 +156,7 @@ def check_directory_tuple_setting(setting_name, setting_value,
 
 
 def validate_installed_app(app_name, python_path_dir, known_apps,
-                           python_path_subdirectory, results):
+                           app_dir_path, django_settings_module, results):
     try:
         import_module(app_name)
         logger.debug("Application '%s' Ok." % app_name)
@@ -172,10 +173,7 @@ def validate_installed_app(app_name, python_path_dir, known_apps,
                     results.error("Django Application '%s' not found. Perhaps you wanted to include the '%s' package in your requirements.txt file" %
                                   (app_name, pkgs[0]))
             else:
-                if len(python_path_subdirectory)>0:
-                    pp_msg = "PYTHONPATH was set to the directory <install_path_to_app>/%s" % python_path_subdirectory
-                else:
-                    pp_msg = "PYTHONPATH was set to the parent of your project root directory."
+                pp_msg = "Your project was installed at %s. PYTHONPATH was set to %s." % (app_dir_path, get_python_path(python_path_dir, django_settings_module))
                 results.error("Django Application '%s' not found. If it is from an external package, add the associated package to the requirements.txt file. If the application is supposed to be a python module included with you project tree, check the value you provided for the settings module. %s" %
                                   (app_name, pp_msg))
         else: # another exception occurred in import
@@ -325,11 +323,7 @@ def validate_settings(app_dir_path, django_settings_module, django_config=None,
     else:
         results.python_path_subdirectory = _get_subdir_component(os.path.dirname(app_dir_path), python_path_dir)
     # get the settings file directory
-    settings_module_comps = django_settings_module.split(".")
-    if len(settings_module_comps)==1:
-        settings_file_directory = python_path_dir
-    else:
-        settings_file_directory = os.path.join(python_path_dir, "/".join(settings_module_comps[0:-1]))
+    settings_file_directory = get_settings_file_directory(python_path_dir, django_settings_module)
 
     # do the import of app's settings
     sys.path = [python_path_dir] + sys.path
@@ -385,7 +379,7 @@ def validate_settings(app_dir_path, django_settings_module, django_config=None,
         known_apps = set(get_apps_for_packages(packages))
         for app_name in settings_module.INSTALLED_APPS:
             validate_installed_app(app_name, python_path_dir, known_apps,
-                                   results.python_path_subdirectory, results)
+                                   app_dir_path, django_settings_module, results)
             installed_apps.append(app_name)
     else:
         installed_apps = []
@@ -478,12 +472,13 @@ def run_installed_tests_as_subprocess(app_dir_path, django_settings_module,
     app_dir_path = os.path.abspath(os.path.expanduser(app_dir_path))
     if not os.path.exists(app_dir_path):
         raise TestSetupError("Django settings file validator: application directory '%s' does not exist" % app_dir_path)
-    python_path = find_python_module(django_settings_module, app_dir_path)
-    if python_path==None:
+    python_path_dir = find_python_module(django_settings_module, app_dir_path)
+    if python_path_dir==None:
         raise TestSetupError("Django settings file validator: unable to find settings module %s under %s" %
                              (django_settings_module, app_dir_path))
     if use_logger == None:
         use_logger = logger
+    python_path = get_python_path(python_path_dir, django_settings_module)
     use_logger.debug("Setting PYTHONPATH to %s" % python_path)
     # we create a temporary file that will contain the results
     tf = tempfile.NamedTemporaryFile(delete=False)
@@ -501,10 +496,11 @@ def run_installed_tests_as_subprocess(app_dir_path, django_settings_module,
             "DJANGO_SETTINGS_MODULE": "%s" % \
                get_deployed_settings_module(django_settings_module)
         }
+        cwd = get_settings_file_directory(python_path_dir, django_settings_module)
         subproc = subprocess.Popen(program_and_args,
                                    env=env, stdin=subprocess.PIPE,
                                    stdout=subprocess.PIPE,
-                                   stderr=subprocess.STDOUT, cwd=app_dir_path)
+                                   stderr=subprocess.STDOUT, cwd=cwd)
         use_logger.debug("Started program %s, pid is %d" % (program_and_args[0],
                                                             subproc.pid))
         subproc.stdin.close()
