@@ -14,10 +14,8 @@ class TestValidationResults(unittest.TestCase):
             raise Exception("This is a test exception")
         except:
             (exc_type, exc_value, exc_traceback) = sys.exc_info()
-        js = create_results_json(SETTINGS_VALIDATION_ERROR_RC,
-                                 "test",
-                                 error_messages=["this is an error message",],
-                                 exception=traceback.format_exception(exc_type, exc_value, exc_traceback))
+        js = FatalErrorResults(SETTINGS_VALIDATION_ERROR_RC,
+                               exc_type, exc_value, exc_traceback).to_json()
         data = json.dumps(js)
         r = ParsedJsonResults(json.loads(data))
 
